@@ -10,7 +10,7 @@ import click
 import humanfriendly
 import pandas
 
-__version__ = '1.1.0'
+__version__ = '1.1.2'
 
 
 logger = logging.getLogger()
@@ -25,7 +25,8 @@ def cli(ctx, debug):
     """
     log_format = '%(asctime)s|%(levelname)s|%(name)s|(%(funcName)s):-%(message)s'
     logging.basicConfig(level=logging.DEBUG if debug else logging.INFO, stream=sys.stdout, format=log_format)
-    logger.info(f'{"-" * 20} Starting Logging for {ctx.invoked_subcommand} (v{__version__}) {"-" * 20}')
+    if ctx.invoked_subcommand not in ['version']:
+        logger.info(f'{"-" * 20} Starting Logging for {ctx.invoked_subcommand} (v{__version__}) {"-" * 20}')
 
 
 def process_column_mappings(source_df, column_mappings):
@@ -86,7 +87,6 @@ def process_mappings(source_df_dict, mappings):
 @click.argument('source', nargs=-1)
 @click.argument('mapping')
 @click.option('-o', '--output', help='relative or absolute path to output file')
-@click.option('--individual', help='performs processing on an individual file basis', is_flag=True)
 @click.pass_context
 def transform(ctx, **kwargs):
     transform_spreadsheets(**kwargs)
@@ -203,7 +203,7 @@ def get_dict_entry(iteration_index, identifier, iterable):
 def mapping_skeleton(**kwargs):
     """Generates a skeleton of the mapping file"""
     try:
-        out_path = get_path(output or 'mapping_skeleton.json', make_dir=True)
+        out_path = get_path(kwargs.get('output') or 'mapping_skeleton.json', make_dir=True)
 
         skeleton = {
             '__instructions__': {
@@ -221,7 +221,7 @@ def mapping_skeleton(**kwargs):
                 {
                     '<worksheet 1 name> or _': {
                         'dest_worksheet_name': '<dest worksheet name> or _',
-                        'merge_columns': '[<name of reference columns for merging multiple spreadsheets>]',
+                        'merge_columns': ["<name of reference columns for merging multiple spreadsheets>"],
                         'columns': [
                             ['<column 1 name>', '<column 1 dest name> or _', '<column 1 dest position> or _'],
                             ['<column 2 name>', '<column 2 dest name> or _', '<column 2 dest position> or _']
